@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -123,7 +128,7 @@ dcl_sgpqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgpqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -271,7 +276,7 @@ dcl_sgpqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgpqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -653,7 +658,7 @@ dcl_sgtrsl(obj, cts)
       cts = rb_funcall(cts, rb_intern("to_str"), 0);
     }
 
-    i_cts = STR2CSTR(cts);
+    i_cts = StringValuePtr(cts);
 
     o_ctl= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_ctl, '\0', DFLT_SIZE+1);
@@ -679,7 +684,7 @@ dcl_sgtrsn(obj, cts)
       cts = rb_funcall(cts, rb_intern("to_str"), 0);
     }
 
-    i_cts = STR2CSTR(cts);
+    i_cts = StringValuePtr(cts);
 
 
     sgtrsn_(i_cts, &o_ntx, (ftnlen)strlen(i_cts));
@@ -703,7 +708,7 @@ dcl_sgtrls(obj, ctl)
       ctl = rb_funcall(ctl, rb_intern("to_str"), 0);
     }
 
-    i_ctl = STR2CSTR(ctl);
+    i_ctl = StringValuePtr(ctl);
 
     o_cts= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cts, '\0', DFLT_SIZE+1);
@@ -729,7 +734,7 @@ dcl_sgtrln(obj, ctl)
       ctl = rb_funcall(ctl, rb_intern("to_str"), 0);
     }
 
-    i_ctl = STR2CSTR(ctl);
+    i_ctl = StringValuePtr(ctl);
 
 
     sgtrln_(i_ctl, &o_ntx, (ftnlen)strlen(i_ctl));
@@ -805,7 +810,7 @@ dcl_isgtrc(obj, ctr)
       ctr = rb_funcall(ctr, rb_intern("to_str"), 0);
     }
 
-    i_ctr = STR2CSTR(ctr);
+    i_ctr = StringValuePtr(ctr);
 
 
     o_rtn_val = isgtrc_(i_ctr, (ftnlen)strlen(i_ctr));
@@ -1402,7 +1407,7 @@ dcl_sgtxu(obj, ux, uy, chars)
 
     i_ux = (real)NUM2DBL(ux);
     i_uy = (real)NUM2DBL(uy);
-    i_chars = STR2CSTR(chars);
+    i_chars = StringValuePtr(chars);
 
 
     sgtxu_(&i_ux, &i_uy, i_chars, (ftnlen)strlen(i_chars));
@@ -1431,7 +1436,7 @@ dcl_sgtxv(obj, vx, vy, chars)
 
     i_vx = (real)NUM2DBL(vx);
     i_vy = (real)NUM2DBL(vy);
-    i_chars = STR2CSTR(chars);
+    i_chars = StringValuePtr(chars);
 
 
     sgtxv_(&i_vx, &i_vy, i_chars, (ftnlen)strlen(i_chars));
@@ -1460,7 +1465,7 @@ dcl_sgtxr(obj, rx, ry, chars)
 
     i_rx = (real)NUM2DBL(rx);
     i_ry = (real)NUM2DBL(ry);
-    i_chars = STR2CSTR(chars);
+    i_chars = StringValuePtr(chars);
 
 
     sgtxr_(&i_rx, &i_ry, i_chars, (ftnlen)strlen(i_chars));
@@ -1810,7 +1815,7 @@ dcl_sgtxzu(obj, ux, uy, chars, rsize, irota, icent, index)
 
     i_ux = (real)NUM2DBL(ux);
     i_uy = (real)NUM2DBL(uy);
-    i_chars = STR2CSTR(chars);
+    i_chars = StringValuePtr(chars);
     i_rsize = (real)NUM2DBL(rsize);
     i_irota = NUM2INT(irota);
     i_icent = NUM2INT(icent);
@@ -1859,7 +1864,7 @@ dcl_sgtxzv(obj, vx, vy, chars, rsize, irota, icent, index)
 
     i_vx = (real)NUM2DBL(vx);
     i_vy = (real)NUM2DBL(vy);
-    i_chars = STR2CSTR(chars);
+    i_chars = StringValuePtr(chars);
     i_rsize = (real)NUM2DBL(rsize);
     i_irota = NUM2INT(irota);
     i_icent = NUM2INT(icent);
@@ -1908,7 +1913,7 @@ dcl_sgtxzr(obj, rx, ry, chars, rsize, irota, icent, index)
 
     i_rx = (real)NUM2DBL(rx);
     i_ry = (real)NUM2DBL(ry);
-    i_chars = STR2CSTR(chars);
+    i_chars = StringValuePtr(chars);
     i_rsize = (real)NUM2DBL(rsize);
     i_irota = NUM2INT(irota);
     i_icent = NUM2INT(icent);
@@ -2779,7 +2784,7 @@ dcl_sgsplc(obj, charx)
       charx = rb_funcall(charx, rb_intern("to_str"), 0);
     }
 
-    i_charx = STR2CSTR(charx);
+    i_charx = StringValuePtr(charx);
 
 
     sgsplc_(i_charx, (ftnlen)strlen(i_charx));
@@ -2864,7 +2869,7 @@ dcl_sgiget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgiget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -2890,7 +2895,7 @@ dcl_sgiset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -2914,7 +2919,7 @@ dcl_sgistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -2952,7 +2957,7 @@ dcl_sgiqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgiqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -3076,7 +3081,7 @@ dcl_sgiqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgiqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -3100,7 +3105,7 @@ dcl_sglget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sglget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -3123,7 +3128,7 @@ dcl_sglset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -3144,7 +3149,7 @@ dcl_sglstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -3182,7 +3187,7 @@ dcl_sglqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sglqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -3303,7 +3308,7 @@ dcl_sglqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sglqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -3329,8 +3334,8 @@ dcl_sgoopn(obj, cprc, com)
       com = rb_funcall(com, rb_intern("to_str"), 0);
     }
 
-    i_cprc = STR2CSTR(cprc);
-    i_com = STR2CSTR(com);
+    i_cprc = StringValuePtr(cprc);
+    i_com = StringValuePtr(com);
 
 
     sgoopn_(i_cprc, i_com, (ftnlen)strlen(i_cprc), (ftnlen)strlen(i_com));
@@ -3349,7 +3354,7 @@ dcl_sgocls(obj, cprc)
       cprc = rb_funcall(cprc, rb_intern("to_str"), 0);
     }
 
-    i_cprc = STR2CSTR(cprc);
+    i_cprc = StringValuePtr(cprc);
 
 
     sgocls_(i_cprc, (ftnlen)strlen(i_cprc));
@@ -3370,7 +3375,7 @@ dcl_sgrget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgrget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -3396,7 +3401,7 @@ dcl_sgrset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -3420,7 +3425,7 @@ dcl_sgrstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -3458,7 +3463,7 @@ dcl_sgrqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgrqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -3582,7 +3587,7 @@ dcl_sgrqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     sgrqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -3594,7 +3599,7 @@ dcl_sgrqin(obj, cp)
 
 }
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_sgpcmd(obj)
@@ -3608,7 +3613,7 @@ dcl_sgpcmd(obj)
 
 #endif
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_sgscmn(obj, nc)
@@ -3631,7 +3636,7 @@ dcl_sgscmn(obj, nc)
 
 #endif
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_sgqcmn(obj)
@@ -3651,7 +3656,7 @@ dcl_sgqcmn(obj)
 
 #endif
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_sgscwd(obj, cxmin, cxmax, cymin, cymax)
@@ -3689,7 +3694,7 @@ dcl_sgscwd(obj, cxmin, cxmax, cymin, cymax)
 
 #endif
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_sgqcwd(obj)
@@ -3853,19 +3858,19 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "sgrqvl", dcl_sgrqvl, 1);
     rb_define_module_function(mDCL, "sgrsvl", dcl_sgrsvl, 2);
     rb_define_module_function(mDCL, "sgrqin", dcl_sgrqin, 1);
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "sgpcmd", dcl_sgpcmd, 0);
 #endif
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "sgscmn", dcl_sgscmn, 1);
 #endif
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "sgqcmn", dcl_sgqcmn, 0);
 #endif
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "sgscwd", dcl_sgscwd, 4);
 #endif
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "sgqcwd", dcl_sgqcwd, 0);
 #endif
 }
