@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -95,7 +100,7 @@ dcl_slsize(obj, cszez)
       cszez = rb_funcall(cszez, rb_intern("to_str"), 0);
     }
 
-    i_cszez = STR2CSTR(cszez);
+    i_cszez = StringValuePtr(cszez);
 
 
     slsize_(i_cszez, (ftnlen)strlen(i_cszez));
@@ -146,7 +151,7 @@ dcl_sldiv(obj, cform, ix, iy)
       iy = rb_funcall(iy, rb_intern("to_i"), 0);
     }
 
-    i_cform = STR2CSTR(cform);
+    i_cform = StringValuePtr(cform);
     i_ix = NUM2INT(ix);
     i_iy = NUM2INT(iy);
 
@@ -245,8 +250,8 @@ dcl_slsttl(obj, cttl, cside, px, py, ht, nt)
       nt = rb_funcall(nt, rb_intern("to_i"), 0);
     }
 
-    i_cttl = STR2CSTR(cttl);
-    i_cside = STR2CSTR(cside);
+    i_cttl = StringValuePtr(cttl);
+    i_cside = StringValuePtr(cside);
     i_px = (real)NUM2DBL(px);
     i_py = (real)NUM2DBL(py);
     i_ht = (real)NUM2DBL(ht);
