@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -110,8 +115,8 @@ dcl_swoopn(obj, cobj, comm)
       comm = rb_funcall(comm, rb_intern("to_str"), 0);
     }
 
-    i_cobj = STR2CSTR(cobj);
-    i_comm = STR2CSTR(comm);
+    i_cobj = StringValuePtr(cobj);
+    i_comm = StringValuePtr(comm);
 
 
     swoopn_(i_cobj, i_comm, (ftnlen)strlen(i_cobj), (ftnlen)strlen(i_comm));
@@ -130,7 +135,7 @@ dcl_swocls(obj, cobj)
       cobj = rb_funcall(cobj, rb_intern("to_str"), 0);
     }
 
-    i_cobj = STR2CSTR(cobj);
+    i_cobj = StringValuePtr(cobj);
 
 
     swocls_(i_cobj, (ftnlen)strlen(i_cobj));
@@ -605,7 +610,7 @@ dcl_swpqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swpqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -753,7 +758,7 @@ dcl_swpqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swpqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -777,7 +782,7 @@ dcl_swcget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
     o_cpara= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cpara, '\0', DFLT_SIZE+1);
@@ -805,8 +810,8 @@ dcl_swcset(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     swcset_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -829,8 +834,8 @@ dcl_swcstx(obj, cp, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
-    i_cpara = STR2CSTR(cpara);
+    i_cp = StringValuePtr(cp);
+    i_cpara = StringValuePtr(cpara);
 
 
     swcstx_(i_cp, i_cpara, (ftnlen)strlen(i_cp), (ftnlen)strlen(i_cpara));
@@ -851,7 +856,7 @@ dcl_swqfnm(obj, cpara)
       cpara = rb_funcall(cpara, rb_intern("to_str"), 0);
     }
 
-    i_cpara = STR2CSTR(cpara);
+    i_cpara = StringValuePtr(cpara);
 
     o_cfname= ALLOCA_N(char, (DFLT_SIZE+1));
     memset(o_cfname, '\0', DFLT_SIZE+1);
@@ -893,7 +898,7 @@ dcl_swcqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swcqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -998,7 +1003,7 @@ dcl_swcsvl(obj, idx, cval)
     }
 
     i_idx = NUM2INT(idx);
-    i_cval = STR2CSTR(cval);
+    i_cval = StringValuePtr(cval);
 
 
     swcsvl_(&i_idx, i_cval, (ftnlen)strlen(i_cval));
@@ -1019,7 +1024,7 @@ dcl_swcqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swcqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1043,7 +1048,7 @@ dcl_swiget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swiget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -1069,7 +1074,7 @@ dcl_swiset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -1093,7 +1098,7 @@ dcl_swistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -1131,7 +1136,7 @@ dcl_swiqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swiqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1255,7 +1260,7 @@ dcl_swiqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swiqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1279,7 +1284,7 @@ dcl_swlget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swlget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -1302,7 +1307,7 @@ dcl_swlset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -1323,7 +1328,7 @@ dcl_swlstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -1361,7 +1366,7 @@ dcl_swlqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swlqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1482,7 +1487,7 @@ dcl_swlqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swlqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1506,7 +1511,7 @@ dcl_swrget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swrget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -1532,7 +1537,7 @@ dcl_swrset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1556,7 +1561,7 @@ dcl_swrstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1594,7 +1599,7 @@ dcl_swrqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swrqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1718,7 +1723,7 @@ dcl_swrqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     swrqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1730,7 +1735,7 @@ dcl_swrqin(obj, cp)
 
 }
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_swcmll(obj)
@@ -1744,7 +1749,7 @@ dcl_swcmll(obj)
 
 #endif
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_swqcmn(obj)
@@ -1764,7 +1769,7 @@ dcl_swqcmn(obj)
 
 #endif
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_swqcmf(obj, ntx)
@@ -1794,7 +1799,7 @@ dcl_swqcmf(obj, ntx)
 
 #endif
 
-#if DCLVER >= 53
+#if DCLVER >= 530
 
 static VALUE
 dcl_swqcmd(obj, ntx)
@@ -1902,16 +1907,16 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "swrqvl", dcl_swrqvl, 1);
     rb_define_module_function(mDCL, "swrsvl", dcl_swrsvl, 2);
     rb_define_module_function(mDCL, "swrqin", dcl_swrqin, 1);
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "swcmll", dcl_swcmll, 0);
 #endif
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "swqcmn", dcl_swqcmn, 0);
 #endif
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "swqcmf", dcl_swqcmf, 1);
 #endif
-#if DCLVER >= 53
+#if DCLVER >= 530
     rb_define_module_function(mDCL, "swqcmd", dcl_swqcmd, 1);
 #endif
 }
