@@ -1,5 +1,5 @@
 /*
- * $Id: p_header,v 1.4 2000/11/27 01:57:01 keiko Exp $
+ * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
  */
 
 #include <stdio.h>
@@ -7,6 +7,11 @@
 #include "libtinyf2c.h"
 #include "narray.h"
 
+/* for compatibility with ruby 1.6 */
+#ifndef StringValuePtr
+#define StringValuePtr(s) STR2CSTR(s)
+#endif
+
 #define DFLT_SIZE 32
 
 extern char    *dcl_obj2ccharary(VALUE, int, int);
@@ -27,31 +32,31 @@ extern void dcl_freecrealary(real *);
 extern void dcl_freeccomplexary(complex *);
 extern void dcl_freeclogicalary(logical *);
 
-/* for functions which return doublereal */
+/* for functions which return real */
 /* fnclib */
-extern doublereal rd2r_(real *);
-extern doublereal rr2d_(real *);
-extern doublereal rexp_(real *, integer *, integer *);
-extern doublereal rfpi_(void);
-extern doublereal rmod_(real *, real *);
+extern real rd2r_(real *);
+extern real rr2d_(real *);
+extern real rexp_(real *, integer *, integer *);
+extern real rfpi_(void);
+extern real rmod_(real *, real *);
 /* gnmlib */
-extern doublereal rgnlt_(real *);
-extern doublereal rgnle_(real *);
-extern doublereal rgngt_(real *);
-extern doublereal rgnge_(real *);
+extern real rgnlt_(real *);
+extern real rgnle_(real *);
+extern real rgngt_(real *);
+extern real rgnge_(real *);
 /* rfalib */
-extern doublereal rmax_(real *, integer *, integer *);
-extern doublereal rmin_(real *, integer *, integer *);
-extern doublereal rsum_(real *, integer *, integer *);
-extern doublereal rave_(real *, integer *, integer *);
-extern doublereal rvar_(real *, integer *, integer *);
-extern doublereal rstd_(real *, integer *, integer *);
-extern doublereal rrms_(real *, integer *, integer *);
-extern doublereal ramp_(real *, integer *, integer *);
+extern real rmax_(real *, integer *, integer *);
+extern real rmin_(real *, integer *, integer *);
+extern real rsum_(real *, integer *, integer *);
+extern real rave_(real *, integer *, integer *);
+extern real rvar_(real *, integer *, integer *);
+extern real rstd_(real *, integer *, integer *);
+extern real rrms_(real *, integer *, integer *);
+extern real ramp_(real *, integer *, integer *);
 /* rfblib */
-extern doublereal rprd_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcov_(real *, real *, integer *, integer *, integer *);
-extern doublereal rcor_(real *, real *, integer *, integer *, integer *);
+extern real rprd_(real *, real *, integer *, integer *, integer *);
+extern real rcov_(real *, real *, integer *, integer *, integer *);
+extern real rcor_(real *, real *, integer *, integer *, integer *);
 
 
 extern VALUE mDCL;
@@ -74,7 +79,7 @@ dcl_ulxlog(obj, cside, nlbl, nticks)
       nticks = rb_funcall(nticks, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_nlbl = NUM2INT(nlbl);
     i_nticks = NUM2INT(nticks);
 
@@ -103,7 +108,7 @@ dcl_ulylog(obj, cside, nlbl, nticks)
       nticks = rb_funcall(nticks, rb_intern("to_i"), 0);
     }
 
-    i_cside = STR2CSTR(cside);
+    i_cside = StringValuePtr(cside);
     i_nlbl = NUM2INT(nlbl);
     i_nticks = NUM2INT(nticks);
 
@@ -308,7 +313,7 @@ dcl_ulpqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ulpqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -456,7 +461,7 @@ dcl_ulpqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ulpqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -480,7 +485,7 @@ dcl_uliget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uliget_(i_cp, &o_ipara, (ftnlen)strlen(i_cp));
@@ -506,7 +511,7 @@ dcl_uliset(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -530,7 +535,7 @@ dcl_ulistx(obj, cp, ipara)
       ipara = rb_funcall(ipara, rb_intern("to_i"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_ipara = NUM2INT(ipara);
 
 
@@ -568,7 +573,7 @@ dcl_uliqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uliqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -692,7 +697,7 @@ dcl_uliqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     uliqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -716,7 +721,7 @@ dcl_ullget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ullget_(i_cp, &o_lpara, (ftnlen)strlen(i_cp));
@@ -739,7 +744,7 @@ dcl_ullset(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -760,7 +765,7 @@ dcl_ullstx(obj, cp, lpara)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_lpara = ((lpara == Qnil)||(lpara == Qfalse)) ? FALSE_ : TRUE_;
 
 
@@ -798,7 +803,7 @@ dcl_ullqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ullqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -919,7 +924,7 @@ dcl_ullqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ullqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -943,7 +948,7 @@ dcl_ulrget(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ulrget_(i_cp, &o_rpara, (ftnlen)strlen(i_cp));
@@ -969,7 +974,7 @@ dcl_ulrset(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -993,7 +998,7 @@ dcl_ulrstx(obj, cp, rpara)
       rpara = rb_funcall(rpara, rb_intern("to_f"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
     i_rpara = (real)NUM2DBL(rpara);
 
 
@@ -1031,7 +1036,7 @@ dcl_ulrqid(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ulrqid_(i_cp, &o_idx, (ftnlen)strlen(i_cp));
@@ -1155,7 +1160,7 @@ dcl_ulrqin(obj, cp)
       cp = rb_funcall(cp, rb_intern("to_str"), 0);
     }
 
-    i_cp = STR2CSTR(cp);
+    i_cp = StringValuePtr(cp);
 
 
     ulrqin_(i_cp, &o_in, (ftnlen)strlen(i_cp));
@@ -1177,7 +1182,7 @@ dcl_ulxsfm(obj, cxfmt)
       cxfmt = rb_funcall(cxfmt, rb_intern("to_str"), 0);
     }
 
-    i_cxfmt = STR2CSTR(cxfmt);
+    i_cxfmt = StringValuePtr(cxfmt);
 
 
     ulxsfm_(i_cxfmt, (ftnlen)strlen(i_cxfmt));
@@ -1215,7 +1220,7 @@ dcl_ulysfm(obj, cyfmt)
       cyfmt = rb_funcall(cyfmt, rb_intern("to_str"), 0);
     }
 
-    i_cyfmt = STR2CSTR(cyfmt);
+    i_cyfmt = StringValuePtr(cyfmt);
 
 
     ulysfm_(i_cyfmt, (ftnlen)strlen(i_cyfmt));
